@@ -14,8 +14,8 @@
 //!}
 //!```
 extern crate native_tls;
-use std::{collections::HashMap, error::Error, fmt, num::ParseIntError};
 
+pub mod error;
 pub mod request;
 pub mod response;
 pub mod url;
